@@ -3,6 +3,7 @@
 #' @templateVar fn Null
 #' @template x
 #' @template checker
+#' @family basetypes
 #' @export
 #' @examples
 #' testNull(NULL)
@@ -21,7 +22,7 @@ check_null = checkNull
 #' @include makeAssertion.R
 #' @template assert
 #' @rdname checkNull
-assertNull = makeAssertionFunction(checkNull)
+assertNull = makeAssertionFunction(checkNull, use.namespace = FALSE)
 
 #' @export
 #' @rdname checkNull
@@ -41,4 +42,4 @@ test_null = testNull
 # #' @include makeExpectation.R
 # #' @template expect
 # #' @rdname checkNull
-expect_null = makeExpectationFunction(checkNull)
+expect_null = makeExpectationFunction(checkNull, use.namespace = FALSE)
